@@ -40,6 +40,11 @@ class LetsEncrypt:
         self.hostname = self._validate_device_connection(hostname)
         self.subject_alternative_names = self._validate_subdelegate_zone(
             subject_alternative_names)
+        self.subdomain = self._get_subdomain(hostname)
+
+    def _get_subdomain(self, hostname: str) -> str:
+        return tldextract.extract(
+            self.hostname).subdomain
 
     def _validate_device_connection(self, hostname, timeout=5):
         try:
@@ -109,33 +114,22 @@ class LetsEncrypt:
             sys.exit(1)
 
     def acme_development(self, csr: str) -> None:  # pragma: no cover
-        subdomain = tldextract.extract(
-            self.hostname).subdomain
         subprocess.call(
-            '{directory}/acme.sh/acme.sh --upgrade -b dev'.format(directory=os.getenv('HOME')), shell=True)
+            '{directory}/acme.sh/acme.sh --upgrade -b dev'.format(directory=os.getenv('HOME')))
         subprocess.call('{directory}/acme.sh/acme.sh --set-default-ca --test --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --preferred-chain "Fake LE Root X2" --force'.format(
-            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'), shell=True)
+            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'))
 
     def acme_production(self, csr: str) -> None:  # pragma: no cover
-        subdomain = tldextract.extract(
-            self.hostname).subdomain
-        print("----------------HERE-------------------")
-        print(subdomain)
-        print(os.getenv('HOME'))
         subprocess.call(
-            '{directory}/acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')), shell=True)
-        print("UPGRADED")
-        subprocess.call('/bin/bash {directory}/acme.sh/acme.sh --set-default-ca --server letsencrypt --preferred-chain "ISRG" --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
-            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'), shell=True)
-        print('COMPLETE')
+            '{directory}/acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')))
+        subprocess.call('{directory}/acme.sh/acme.sh --set-default-ca --server letsencrypt --preferred-chain "ISRG" --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
+            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'))
 
     def acme_local(self, csr: str) -> None:  # pragma: no cover
-        subdomain = tldextract.extract(
-            self.hostname).subdomain
         subprocess.call(
             '{directory}/.acme.sh/acme.sh --upgrade -b dev'.format(directory=os.getenv('HOME')), shell=True)
         subprocess.call('{directory}/.acme.sh/acme.sh --set-default-ca --test --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --preferred-chain "Fake LE Root X2" --force'.format(
-            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'), shell=True)
+            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'), shell=True)
 
     def acme_private_ca_local(self, csr: str, acme_server_url: str) -> None:  # pragma: no cover
         prefix = os.environ['PREFIX']
@@ -144,12 +138,10 @@ class LetsEncrypt:
         with open('root_ca.crt', 'w') as outfile:
             outfile.write(root_certificate)
 
-        subdomain = tldextract.extract(
-            self.hostname).subdomain
         subprocess.call(
             '{directory}/.acme.sh/acme.sh --upgrade -b dev'.format(directory=os.getenv('HOME')), shell=True)
         subprocess.call('{directory}/.acme.sh/acme.sh --set-default-ca --server {server} --ca-bundle root_ca.crt --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
-            directory=os.getenv('HOME'), server=acme_server_url, csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'), shell=True)
+            directory=os.getenv('HOME'), server=acme_server_url, csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'), shell=True)
 
     def acme_private_ca_production(self, csr: str, acme_server_url: str) -> None:  # pragma: no cover
         prefix = os.environ['PREFIX']
@@ -158,8 +150,7 @@ class LetsEncrypt:
         with open('root_ca.crt', 'w') as outfile:
             outfile.write(root_certificate)
 
-        subdomain = tldextract.extract(self.hostname).subdomain
         subprocess.call(
-            '{directory}/acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')), shell=True)
+            '{directory}/acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')))
         subprocess.call('{directory}/acme.sh/acme.sh --set-default-ca --server {server} --ca-bundle root_ca.crt --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
-            directory=os.getenv('HOME'), server=acme_server_url, csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'), shell=True)
+            directory=os.getenv('HOME'), server=acme_server_url, csr=f'{csr}', domain_validation=f'{self.subdomain}.{self.subdelegate}'))
